Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(717)

Unified Diff: runtime/include/dart_api.h

Issue 2068833002: Change Dart_DefaultCanonicalizeUrl to accept the library url string instead of a library, this is u… (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/include/dart_api.h
diff --git a/runtime/include/dart_api.h b/runtime/include/dart_api.h
index e27d70e44e4217130f68a6abc9af3ca992f477c1..85748de0eafdedba40de0e5e98da9a62ff1e98cd 100755
--- a/runtime/include/dart_api.h
+++ b/runtime/include/dart_api.h
@@ -2692,15 +2692,15 @@ DART_EXPORT Dart_Handle Dart_SetLibraryTagHandler(
* This canonicalization function should be sufficient for most
* embedders to implement the Dart_kCanonicalizeUrl tag.
*
* \param library The library relative to which the url is being
* resolved.
Cutch 2016/06/14 21:38:31 s/library_url/base_url ?
siva 2016/06/14 22:23:29 Done.
+ * being resolved.
* \param url The url being resolved and canonicalized. This
* parameter is a string handle.
*
* \return If no error occurs, a String object is returned. Otherwise
* an error handle is returned.
*/
-DART_EXPORT Dart_Handle Dart_DefaultCanonicalizeUrl(Dart_Handle library,
+DART_EXPORT Dart_Handle Dart_DefaultCanonicalizeUrl(Dart_Handle library_url,
Dart_Handle url);
/**
@@ -2692,15 +2692,15 @@ DART_EXPORT Dart_Handle Dart_SetLibraryTagHandler(
* embedders to implement the Dart_kCanonicalizeUrl tag.
*
- * \param library The library relative to which the url is being
- * resolved.
+ * \param library_url The library url relative to which the url is
Cutch 2016/06/14 21:38:31 s/library_url/base_url ?
siva 2016/06/14 22:23:29 Done.

Powered by Google App Engine
This is Rietveld 408576698